@@ -1,9 +1,9 @@
 # Classes
 from roblopy.user import Users
-from roblopy.user import GetUserFromUsername
-from roblopy.user import GetUserFromId
+from roblopy.user import User
 from roblopy.friends import Friends
 from roblopy.assets import Assets
 from roblopy.assets import Asset
 from roblopy.groups import Groups
 from roblopy.groups import Group
+from .utils.errors import BadStatus, NotFound, BadRequest
\ No newline at end of file
