@@ -1,22 +1,22 @@
-import requests
+from .utils.request import get
 
 class Friends:
     @staticmethod
     def GetFriends(userId):
-        return requests.get("https://api.roblox.com/users/" + str(userId) + "/friends").json()
+        return get("https://api.roblox.com/users/" + str(userId) + "/friends").json()
 
     @staticmethod
     def GetFirstFriend(userId):
-        return requests.get("https://api.roblox.com/users/" + str(userId) + "/friends").json()[-1]
+        return get("https://api.roblox.com/users/" + str(userId) + "/friends").json()[-1]
 
     @staticmethod
     def GetRecentFriend(userId):
-        return requests.get("https://api.roblox.com/users/" + str(userId) + "/friends").json()[0]
+        return get("https://api.roblox.com/users/" + str(userId) + "/friends").json()[0]
 
     @staticmethod
     def UsersAreFriends(userId1, userId2):
-        response1 = requests.get("https://api.roblox.com/users/" + str(userId1) + "/friends").json()
-        response2 = requests.get("https://api.roblox.com/users/" + str(userId2) + "/friends").json()
+        response1 = get("https://api.roblox.com/users/" + str(userId1) + "/friends").json()
+        response2 = get("https://api.roblox.com/users/" + str(userId2) + "/friends").json()
         friends_list = [userId1, userId2]
         friendship = False
 
